| nbl_results | R Documentation |
Returns a data frame of all results in either wide or long form of all NBL matches played since 1979
nbl_results(wide_or_long)
wide_or_long |
either 'wide' or 'long' to get either one row per match, or a row for each team for each match |
returns a dataframe of match results
try({
results_wide <- nbl_results(wide_or_long="wide")
results_long <- nbl_results(wide_or_long="long")
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.