Learn R Programming

nblR (version 0.0.4)

nbl_results: Get match results for all NBL matches

Description

Returns a data frame of all results in either wide or long form of all NBL matches played since 1979

Usage

nbl_results(wide_or_long)

Value

returns a dataframe of match results

Arguments

wide_or_long

either 'wide' or 'long' to get either one row per match, or a row for each team for each match

Examples

Run this code
try({
results_wide <- nbl_results(wide_or_long="wide")
results_long <- nbl_results(wide_or_long="long")
})

Run the code above in your browser using DataLab