powered by
Returns a data frame of all results in either wide or long form of all NBL matches played since 1979
nbl_results(wide_or_long)
returns a dataframe of match results
either 'wide' or 'long' to get either one row per match, or a row for each team for each match
try({ results_wide <- nbl_results(wide_or_long="wide") results_long <- nbl_results(wide_or_long="long") })
Run the code above in your browser using DataLab